summaryrefslogtreecommitdiff
path: root/CMake
diff options
context:
space:
mode:
Diffstat (limited to 'CMake')
-rw-r--r--CMake/FindBerkeley.cmake (renamed from CMake/FindBerkeleyDB.cmake)18
-rw-r--r--CMake/FindGCRYPT.cmake (renamed from CMake/FindGcrypt.cmake)0
-rw-r--r--CMake/FindSECCOMP.cmake (renamed from CMake/FindSeccomp.cmake)0
-rw-r--r--CMake/FindZSTD.cmake (renamed from CMake/FindZstd.cmake)0
4 files changed, 9 insertions, 9 deletions
diff --git a/CMake/FindGcrypt.cmake b/CMake/FindGCRYPT.cmake
index 56bfc9fef..56bfc9fef 100644
--- a/CMake/FindGcrypt.cmake
+++ b/CMake/FindGCRYPT.cmake
diff --git a/CMake/FindSeccomp.cmake b/CMake/FindSECCOMP.cmake
index 5cfd13a37..5cfd13a37 100644
--- a/CMake/FindSeccomp.cmake
+++ b/CMake/FindSECCOMP.cmake
diff --git a/CMake/FindZstd.cmake b/CMake/FindZSTD.cmake
index 68118049b..68118049b 100644
--- a/CMake/FindZstd.cmake
+++ b/CMake/FindZSTD.cmake
diff --git a/CMake/FindBerkeleyDB.cmake b/CMake/FindBerkeley.cmake
index 34bc3b0d1..a6215d728 100644
--- a/CMake/FindBerkeleyDB.cmake
+++ b/CMake/FindBerkeley.cmake
@@ -1,10 +1,10 @@
# - Try to find Berkeley DB
# Once done this will define
#
# BERKELEY_DB_FOUND - system has Berkeley DB
# BERKELEY_DB_INCLUDE_DIRS - the Berkeley DB include directory
# BERKELEY_DB_LIBRARIES - Link these to use Berkeley DB
# BERKELEY_DB_DEFINITIONS - Compiler switches required for using Berkeley DB
# Copyright (c) 2006, Alexander Dymo, <adymo@kdevelop.org>
# Copyright (c) 2016, Julian Andres Klode <jak@debian.org>
@@ -35,7 +35,7 @@
# We need NO_DEFAULT_PATH here, otherwise CMake helpfully picks up the wrong
# db.h on BSD systems instead of the Berkeley DB one.
-find_path(BERKELEY_DB_INCLUDE_DIRS db.h
+find_path(BERKELEY_INCLUDE_DIRS db.h
${CMAKE_INSTALL_FULL_INCLUDEDIR}/db5
/usr/local/include/db5
/usr/include/db5
@@ -51,9 +51,9 @@ find_path(BERKELEY_DB_INCLUDE_DIRS db.h
NO_DEFAULT_PATH
)
-find_library(BERKELEY_DB_LIBRARIES NAMES db db-5)
+find_library(BERKELEY_LIBRARIES NAMES db db-5)
include(FindPackageHandleStandardArgs)
-find_package_handle_standard_args(Berkeley "Could not find Berkeley DB >= 4.1" BERKELEY_DB_INCLUDE_DIRS BERKELEY_DB_LIBRARIES)
-# show the BERKELEY_DB_INCLUDE_DIRS and BERKELEY_DB_LIBRARIES variables only in the advanced view
-mark_as_advanced(BERKELEY_DB_INCLUDE_DIRS BERKELEY_DB_LIBRARIES)
+find_package_handle_standard_args(Berkeley "Could not find Berkeley DB >= 4.1" BERKELEY_INCLUDE_DIRS BERKELEY_LIBRARIES)
+# show the BERKELEY_INCLUDE_DIRS and BERKELEY_LIBRARIES variables only in the advanced view
+mark_as_advanced(BERKELEY_INCLUDE_DIRS BERKELEY_LIBRARIES)
@@ -1,10 +1,10 @@
# Once done this will define
#
-# BERKELEY_DB_FOUND - system has Berkeley DB
-# BERKELEY_DB_INCLUDE_DIRS - the Berkeley DB include directory
-# BERKELEY_DB_LIBRARIES - Link these to use Berkeley DB
-# BERKELEY_DB_DEFINITIONS - Compiler switches required for using Berkeley DB
+# BERKELEY_FOUND - system has Berkeley DB
+# BERKELEY_INCLUDE_DIRS - the Berkeley DB include directory
+# BERKELEY_LIBRARIES - Link these to use Berkeley DB
+# BERKELEY_DEFINITIONS - Compiler switches required for using Berkeley DB
# Copyright (c) 2006, Alexander Dymo, <adymo@kdevelop.org>
# Copyright (c) 2016, Julian Andres Klode <jak@debian.org>